@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmedian.c,v 1.62 2009/07/11 03:16:29 guru Exp $
+ *    $Id: blockmedian.c,v 1.66 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ int main (int argc, char **argv)
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct BLOCKMEDIAN_CTRL *) New_Blockmedian_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct BLOCKMEDIAN_CTRL *) New_blockmedian_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	GMT_grd_init (&h, argc, argv, FALSE);
 
@@ -277,7 +277,7 @@ int main (int argc, char **argv)
 		if (GMT_io.io_header[GMT_IN]) {
 			for (i = 0; i < GMT_io.n_header_recs; i++) {
 				not_used = GMT_fgets (buffer, BUFSIZ, fp);
-				buffer[strlen(buffer)-1] = 0;
+				GMT_chop (buffer);
 				if (first && GMT_io.io_header[GMT_OUT]) (Ctrl->W.weighted[GMT_OUT] && !(Ctrl->W.weighted[GMT_IN])) ? fprintf (GMT_stdout, "%s weights\n", buffer) : fprintf (GMT_stdout, "%s\n", buffer);
 			}
 			first = FALSE;
@@ -397,7 +397,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)data);
 	GMT_free ((void *)z_tmp);
 
-	Free_Blockmedian_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_blockmedian_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
