@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdimage.c,v 1.88 2009/07/08 21:41:40 guru Exp $
+ *	$Id: grdimage.c,v 1.111 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
  * Author:	Paul Wessel
  * Date:	17-SEP-2001
  * Ver:		4
+ *
  */
 
 #include "gmt.h"
@@ -36,6 +37,12 @@ struct GRDIMAGE_CTRL {
 		BOOLEAN active;
 		char *file;
 	} C;
+#ifdef USE_GDAL
+	struct D {	/* -D to read gdal file */
+		BOOLEAN active;
+		BOOLEAN mode;	/* Use info of -R option to reference image */
+	} D;
+#endif
 	struct E {	/* -Ei|<dpi> */
 		BOOLEAN active;
 		BOOLEAN device_dpi;
@@ -88,12 +95,19 @@ int main (int argc, char **argv)
 	struct GMT_EDGEINFO edgeinfo;
 	struct GRDIMAGE_CTRL *Ctrl;
 
+#ifdef USE_GDAL
+	BOOLEAN do_indexed = FALSE;
+	unsigned char *r_table = NULL, *g_table = NULL, *b_table = NULL;
+	struct GDALREAD_CTRL *to_gdalread;
+	struct GD_CTRL *from_gdalread;
+#endif
+
 	void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g);
-	void *New_Grdimage_Ctrl (), Free_Grdimage_Ctrl (struct GRDIMAGE_CTRL *C);
+	void *New_grdimage_Ctrl (), Free_grdimage_Ctrl (struct GRDIMAGE_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDIMAGE_CTRL *)New_Grdimage_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDIMAGE_CTRL *)New_grdimage_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	grdfile[0] = grdfile[1] = grdfile[2] = CNULL;
 	west = east = south = north = 0.0;
@@ -127,6 +141,12 @@ int main (int argc, char **argv)
 					Ctrl->C.active = TRUE;
 					Ctrl->C.file = strdup (&argv[i][2]);
 					break;
+#ifdef USE_GDAL
+				case 'D':
+					Ctrl->D.active = TRUE;
+					if (argv[i][2] == 'r') Ctrl->D.mode = TRUE;
+					break;
+#endif
 				case 'E':
 					Ctrl->E.active = TRUE;
 					if (argv[i][2] == 'i')	/* Interpolate image to device resolution */
@@ -236,19 +256,29 @@ int main (int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"grdimage %s - Plot grid files in 2-D\n\n", GMT_VERSION);
+#ifdef USE_GDAL
+		fprintf (stderr, "usage: grdimage <grd_z|grd_r grd_g grd_b> %s [%s] [-C<cpt_file>] [-D[r]] [-Ei|<dpi>] [-G[f|b]<rgb>]\n", GMT_J_OPT, GMT_B_OPT);
+#else
 		fprintf (stderr, "usage: grdimage <grd_z|grd_r grd_g grd_b> %s [%s] [-C<cpt_file>] [-Ei|<dpi>] [-G[f|b]<rgb>]\n", GMT_J_OPT, GMT_B_OPT);
+#endif
 		fprintf (stderr, "\t[-I<intensity_file>] [-K] [-M] [-N] [-O] [-P] [-Q] [%s] [-S[-]b|c|l|n[/<threshold>]] [-T]\n", GMT_Rgeo_OPT);
 		fprintf (stderr, "\t[%s] [-V] [%s] [%s] [%s]\n\n", GMT_U_OPT, GMT_X_OPT, GMT_Y_OPT, GMT_c_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
-		fprintf (stderr,"\t<grd_z> is data set to be plotted.  Its z-values are in user units and will be\n");
-		fprintf (stderr,"\t  converted to rgb colors via the cpt file.  Alternatively, give three separate\n");
-		fprintf (stderr,"\t  grid files that contain the red, green, and blue components in the 0-255 range.\n");
+		fprintf (stderr, "\t<grd_z> is data set to be plotted.  Its z-values are in user units and will be\n");
+		fprintf (stderr, "\t  converted to rgb colors via the cpt file.  Alternatively, give three separate\n");
+		fprintf (stderr, "\t  grid files that contain the red, green, and blue components in the 0-255 range.\n");
+#ifdef USE_GDAL
+		fprintf (stderr, "\t  If -D is used then <grd_z> is instead expected to be an image.\n");
+#endif
 		GMT_explain_option ('j');
 		fprintf (stderr,"\n\tOPTIONS:\n");
 		GMT_explain_option ('b');
 		fprintf (stderr, "\t-C color palette file to convert z to rgb\n");
+#ifdef USE_GDAL
+		fprintf (stderr, "\t-D is used to read an image via GDAL.  Append r to equate image region to -R region.\n");
+#endif
 		fprintf (stderr, "\t-E sets dpi for the projected grid which must be constructed\n");
 		fprintf (stderr, "\t   if -Jx or -Jm is not selected [Default gives same size as input grid]\n");
 		fprintf (stderr, "\t   Give i to do the interpolation in PostScript at device resolution.\n");
@@ -285,6 +315,9 @@ int main (int argc, char **argv)
 			error++;
 		}
 	}
+#ifdef USE_GDAL
+	if (Ctrl->D.active) {} else
+#endif
 	if (!Ctrl->C.file && !do_rgb) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Must specify color palette table\n", GMT_program);
 		error++;
@@ -307,20 +340,122 @@ int main (int argc, char **argv)
 	}
 	if (error) exit (EXIT_FAILURE);
 
-	/* Get color palette file */
+#ifdef USE_GDAL
+	if (Ctrl->D.active) {
+		int pad;
+		/* One more test though */
+		if (Ctrl->I.active) {
+			fprintf (stderr, "%s: GMT SYNTAX ERROR cannot use -D and -I options.\n", GMT_program);
+			exit (EXIT_FAILURE);
+		}
+		if (Ctrl->D.mode && !project_info.region_supplied) {
+			fprintf (stderr, "%s: GMT WARNING: -Dr without -R makes no sense. Ignoring -Dr.\n", GMT_program);
+			Ctrl->D.mode = FALSE;
+		}
+
+		/* Allocate new control structures */
+		to_gdalread = (struct GDALREAD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GDALREAD_CTRL), "New_gdalread_Ctrl");
+		from_gdalread = (struct GD_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GD_CTRL), "New_gd_Ctrl");
+		to_gdalread->F.active = 1;
+
+		if (project_info.region_supplied && !Ctrl->D.mode) {
+			char	strR [128]; 
+			sprintf(strR, "-R%.10f/%.10f/%.10f/%.10f", west, east, south, north);
+			to_gdalread->R.region = strR;
+		}
+
+		pad = (project_info.projection != GMT_LINEAR || project_info.xyz_projection[0] == GMT_LOG10 || 
+			project_info.xyz_projection[0] == GMT_POW || project_info.xyz_projection[1] == GMT_LOG10 || 
+			project_info.xyz_projection[1] == GMT_POW || Ctrl->E.dpi > 0);
+		if (pad) {
+			to_gdalread->p.active = 1;
+			to_gdalread->p.pad = 2;
+		}
+
+		if (GMT_gdalread ( grdfile[0], to_gdalread, from_gdalread)) {
+			fprintf (stderr, "%s: ERROR reading file with gdalread.\n", GMT_program);
+			exit (EXIT_FAILURE);
+		}
+
+		if (!from_gdalread->UInt8.active) {
+			fprintf(stderr, "%s: Using data type other than byte (unsigned char) is not implemented\n", GMT_program);
+			exit (EXIT_FAILURE);
+		}
+
+		do_rgb = (from_gdalread->RasterCount == 3);
+		if (do_rgb) n_grids = 3;	/* To be compatible with original algo */
+
+		if (gmtdefs.verbose && from_gdalread->ProjectionRefPROJ4 != CNULL)
+			fprintf (stderr, "Data projection (Proj4 type)\n\t%s\n", from_gdalread->ProjectionRefPROJ4);
+
+		GMT_grd_init (&g_head[i], argc, argv, FALSE);
+		GMT_grd_init (&r_head[i], argc, argv, FALSE);
+		if (!Ctrl->D.mode) {
+			g_head[0].x_min = g_head[1].x_min = g_head[2].x_min = from_gdalread->hdr[0];
+			g_head[0].x_max = g_head[1].x_max = g_head[2].x_max = from_gdalread->hdr[1];
+			g_head[0].y_min = g_head[1].y_min = g_head[2].y_min = from_gdalread->hdr[2];
+			g_head[0].y_max = g_head[1].y_max = g_head[2].y_max = from_gdalread->hdr[3];
+			g_head[0].x_inc = g_head[1].x_inc = g_head[2].x_inc = from_gdalread->hdr[7];
+			g_head[0].y_inc = g_head[1].y_inc = g_head[2].y_inc = from_gdalread->hdr[8];
+		}
+		else {
+			g_head[0].x_min = g_head[1].x_min = g_head[2].x_min = west;
+			g_head[0].x_max = g_head[1].x_max = g_head[2].x_max = east;
+			g_head[0].y_min = g_head[1].y_min = g_head[2].y_min = south;
+			g_head[0].y_max = g_head[1].y_max = g_head[2].y_max = north;
+			g_head[0].x_inc = g_head[1].x_inc = g_head[2].x_inc = (g_head[0].x_max - g_head[0].x_min) / from_gdalread->RasterXsize;
+			g_head[0].y_inc = g_head[1].y_inc = g_head[2].y_inc = (g_head[0].y_max - g_head[0].y_min) / from_gdalread->RasterYsize;
+		}
+		g_head[0].nx = g_head[1].nx = g_head[2].nx = from_gdalread->RasterXsize;
+		g_head[0].ny = g_head[1].ny = g_head[2].ny = from_gdalread->RasterYsize;
+		g_head[0].node_offset = g_head[1].node_offset = g_head[2].node_offset = (int)from_gdalread->hdr[6];
+	}
+#endif
+
+	/* Get/calculate a color palette file */
+
+	if (!do_rgb) {
+		if (Ctrl->C.active)
+			GMT_read_cpt (Ctrl->C.file);
+#ifdef USE_GDAL
+		else if (Ctrl->D.active) {
+			if (from_gdalread->ColorMap == NULL && !strncmp(from_gdalread->ColorInterp,"Gray",4)) {
+    				r_table = (unsigned char *) malloc(256 * sizeof(*r_table));
+				for (i = 0; i < 256; i++) r_table[i] = (unsigned char)i;
+				GMT_gray = TRUE;
+			}
+			else if (from_gdalread->ColorMap != NULL) {
+    				r_table = (unsigned char *) malloc(256 * sizeof(*r_table));
+    				g_table = (unsigned char *) malloc(256 * sizeof(*g_table));
+    				b_table = (unsigned char *) malloc(256 * sizeof(*b_table));
+				for (i = 0; i < 256; i++) {
+					r_table[i] = from_gdalread->ColorMap[i*4];	/* 4 because color table is RGBA */
+					g_table[i] = from_gdalread->ColorMap[i*4 + 1];
+					b_table[i] = from_gdalread->ColorMap[i*4 + 2];
+				}
+				do_indexed = TRUE;		/* Now it will be RGB */
+				GMT_gray = FALSE;
+			}
+		}
+#endif
+	}
 
-	if (!do_rgb) GMT_read_cpt (Ctrl->C.file);
 	PS_interpolate = (Ctrl->E.device_dpi) ? -1 : +1;
 	PS_colormask   = (Ctrl->Q.active) ? -1 : +1;;
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Allocates memory and read data file\n", GMT_program);
 
-	for (i = 0; i < n_grids; i++) {
-		GMT_grd_init (&g_head[i], argc, argv, FALSE);
-		GMT_grd_init (&r_head[i], argc, argv, FALSE);
-
-		GMT_err_fail (GMT_read_grd_info (grdfile[i], &g_head[i]), grdfile[i]);
+#ifdef USE_GDAL
+	if (!Ctrl->D.active) {
+#endif
+		for (i = 0; i < n_grids; i++) {
+			GMT_grd_init (&g_head[i], argc, argv, FALSE);
+			GMT_grd_init (&r_head[i], argc, argv, FALSE);
+			GMT_err_fail (GMT_read_grd_info (grdfile[i], &g_head[i]), grdfile[i]);
+		}
+#ifdef USE_GDAL
 	}
+#endif
 	if (do_rgb) {	/* Must ensure all three grids are coregistered */
 		if (!(g_head[0].x_min == g_head[1].x_min && g_head[0].x_min == g_head[2].x_min)) error++;
 		if (!(g_head[0].y_min == g_head[1].y_min && g_head[0].y_min == g_head[2].y_min)) error++;
@@ -356,7 +491,7 @@ int main (int argc, char **argv)
 		GMT_plotinit (argc, argv);
 		GMT_map_basemap ();
 		GMT_plotend ();
-		Free_Grdimage_Ctrl (Ctrl);	/* Deallocate control structure */
+		Free_grdimage_Ctrl (Ctrl);	/* Deallocate control structure */
 		GMT_end (argc, argv);
 		exit (EXIT_SUCCESS);
 	}
@@ -366,6 +501,14 @@ int main (int argc, char **argv)
 
 	nx = GMT_get_n (data_west, data_east, g_head[0].x_inc, g_head[0].node_offset);
 	ny = GMT_get_n (data_south, data_north, g_head[0].y_inc, g_head[0].node_offset);
+
+#ifdef USE_GDAL
+	if (Ctrl->D.active) {	/* Trust more on info from gdal to make it more stable against pixel vs grid registration troubles */
+		nx = from_gdalread->RasterXsize;
+		ny = from_gdalread->RasterYsize;
+	}
+#endif
+
 #if 0
 	fprintf (stderr, "%g %g %g %g / %g %g\n", g_head[0].x_min, g_head[0].x_max, g_head[0].y_min, g_head[0].y_max, g_head[0].x_inc, g_head[0].y_inc);
 	fprintf (stderr, "%g %g %g %g\n", data_west, data_east, data_south, data_north);
@@ -383,10 +526,22 @@ int main (int argc, char **argv)
 
 	/* Read data */
 
-	for (i = 0; i < n_grids; i++) {
-		tmp1[i] = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
-		GMT_err_fail (GMT_read_grd (grdfile[i], &g_head[i], tmp1[i], data_west, data_east, data_south, data_north, GMT_pad, FALSE), grdfile[i]);
+#ifdef USE_GDAL
+	if (Ctrl->D.active) {
+		for (i = 0; i < n_grids; i++) {
+			tmp1[i] = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
+			for (j = 0; j < nm; j++) tmp1[i][j] = (float)from_gdalread->UInt8.data[j+i*nm];
+		}
 	}
+	else {
+#endif
+		for (i = 0; i < n_grids; i++) {
+			tmp1[i] = (float *) GMT_memory (VNULL, nm, sizeof (float), GMT_program);
+			GMT_err_fail (GMT_read_grd (grdfile[i], &g_head[i], tmp1[i], data_west, data_east, data_south, data_north, GMT_pad, FALSE), grdfile[i]);
+		}
+#ifdef USE_GDAL
+	}
+#endif
 
 	/* If given, get intensity file or compute intensities */
 
@@ -485,6 +640,17 @@ int main (int argc, char **argv)
 			kk = ((size_t)r_head[0].nx) * ((size_t)(normal_y ? j : r_head[0].ny - j - 1));
 			for (i = 0; i < r_head[0].nx; i++) {	/* Compute rgb for each pixel */
 				node = kk + (normal_x ? i : r_head[0].nx - i - 1);
+#ifdef USE_GDAL
+				if (Ctrl->D.active && !do_rgb) {
+					index = -1;	/* Ensures no illumination done later */
+					rgb[0] = r_table[(int)map[0][node]];
+					if (do_indexed) {
+						rgb[1] = g_table[(int)map[0][node]];
+						rgb[2] = b_table[(int)map[0][node]];
+					}
+				}
+				else
+#endif
 				if (do_rgb) {
 					for (k = 0; k < 3; k++) {
 						if (GMT_is_fnan (map[k][node])) {	/* If one is NaN they are all assumed to be NaN */
@@ -500,6 +666,7 @@ int main (int argc, char **argv)
 				}
 				else
 					index = GMT_get_rgb_from_z (map[0][node], rgb);
+
 				if (Ctrl->I.active && index != -1) GMT_illuminate (intensity[node], rgb);
 
 				if (GMT_gray)	/* Color table only has grays, pick r */
@@ -620,7 +787,21 @@ int main (int argc, char **argv)
 
 	GMT_plotend ();
 
-	Free_Grdimage_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdimage_Ctrl (Ctrl);	/* Deallocate control structure */
+
+#ifdef USE_GDAL
+	if (Ctrl->D.active) {
+		if (r_table) free((void *) r_table);
+		if (g_table) {
+			free((void *) g_table);
+			free((void *) b_table);
+		}
+		GMT_free ((void *)to_gdalread);
+		GMT_free ((void *)from_gdalread->UInt8.data);
+		if (from_gdalread->ColorMap == NULL) GMT_free((void *) from_gdalread->ColorMap);
+		GMT_free((void *) from_gdalread);
+	}
+#endif
 
 	GMT_end (argc, argv);
 	exit (EXIT_SUCCESS);
@@ -690,10 +871,10 @@ void GMT_set_proj_limits (struct GRD_HEADER *r, struct GRD_HEADER *g)
 	}
 }
 
-void *New_Grdimage_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdimage_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDIMAGE_CTRL *C;
 
-	C = (struct GRDIMAGE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDIMAGE_CTRL), "New_Grdimage_Ctrl");
+	C = (struct GRDIMAGE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct GRDIMAGE_CTRL), "New_grdimage_Ctrl");
 
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 
@@ -704,7 +885,7 @@ void *New_Grdimage_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void Free_Grdimage_Ctrl (struct GRDIMAGE_CTRL *C) {	/* Deallocate control structure */
+void Free_grdimage_Ctrl (struct GRDIMAGE_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);
 	if (C->I.file) free ((void *)C->I.file);
 	GMT_free ((void *)C);
