@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: grdvolume.c,v 1.46 2009/05/13 21:06:43 guru Exp $
+ *	$Id: grdvolume.c,v 1.49 2010/01/05 01:15:46 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -79,11 +79,11 @@ int main (int argc, char **argv)
 	void NS_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN right, double *dv, double *da);
 	void EW_trapezoid (float f[], GMT_LONG ij, GMT_LONG nx, BOOLEAN top, double *dv, double *da);
 	GMT_LONG ors_find_kink (double y[], GMT_LONG n, GMT_LONG mode);
-	void *New_Grdvolume_Ctrl (), Free_Grdvolume_Ctrl (struct GRDVOLUME_CTRL *C);
+	void *New_grdvolume_Ctrl (), Free_grdvolume_Ctrl (struct GRDVOLUME_CTRL *C);
 
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct GRDVOLUME_CTRL *) New_Grdvolume_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct GRDVOLUME_CTRL *) New_grdvolume_Ctrl ();	/* Allocate and initialize a new control structure */
 	
 	west = east = south = north = 0.0;
 
@@ -386,7 +386,7 @@ int main (int argc, char **argv)
 	GMT_free ((void *)vol);
 	GMT_free ((void *)height);
 
-	Free_Grdvolume_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_grdvolume_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -615,10 +615,10 @@ double median3 (double x[])
 	}
 }
 
-void *New_Grdvolume_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_grdvolume_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct GRDVOLUME_CTRL *C;
 	
-	C = (struct GRDVOLUME_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GRDVOLUME_CTRL), "New_Grdvolume_Ctrl");
+	C = (struct GRDVOLUME_CTRL *) GMT_memory (VNULL, 1, sizeof (struct GRDVOLUME_CTRL), "New_grdvolume_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->L.value = GMT_d_NaN;
@@ -626,6 +626,6 @@ void *New_Grdvolume_Ctrl () {	/* Allocate and initialize a new control structure
 	return ((void *)C);
 }
 
-void  Free_Grdvolume_Ctrl (struct GRDVOLUME_CTRL *C) {	/* Deallocate control structure */
+void  Free_grdvolume_Ctrl (struct GRDVOLUME_CTRL *C) {	/* Deallocate control structure */
 	GMT_free ((void *)C);	
 }
