@@ -1,8 +1,8 @@
 /*--------------------------------------------------------------------
- *	$Id: psscale.c,v 1.99 2009/07/10 22:22:06 remko Exp $
+ *	$Id: psscale.c,v 1.104 2010/01/14 07:15:19 guru Exp $
  *
- *	Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
- *	See COPYING file for copying and redistribution conditions.
+ *	Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
+ *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -107,11 +107,11 @@ int main(int argc, char **argv)
 	void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG bit_dpi, GMT_LONG flip, BOOLEAN B_set, BOOLEAN equi, 
 	   BOOLEAN horizontal, BOOLEAN logscl, BOOLEAN intens, double *max_intens, BOOLEAN skip_lines, GMT_LONG extend, double e_length, double gap, BOOLEAN interval_annot, BOOLEAN monochrome);
 
-	void *New_Psscale_Ctrl (), Free_Psscale_Ctrl (struct PSSCALE_CTRL *C);
+	void *New_psscale_Ctrl (), Free_psscale_Ctrl (struct PSSCALE_CTRL *C);
 	
 	argc = GMT_begin (argc, argv);
 
-	Ctrl = (struct PSSCALE_CTRL *)New_Psscale_Ctrl ();	/* Allocate and initialize a new control structure */
+	Ctrl = (struct PSSCALE_CTRL *)New_psscale_Ctrl ();	/* Allocate and initialize a new control structure */
 
 	/* Check and interpret the command line arguments */
 
@@ -355,7 +355,8 @@ int main(int argc, char **argv)
 				fprintf (stderr, "%s: -Z file %s has more slices than -C file %s!\n", GMT_program, Ctrl->Z.file, Ctrl->C.file);
 				exit (EXIT_FAILURE);
 			}
-			if (line[0] == '#' || line[0] == '\n') continue;	/* Skip comments and blank lines */
+			GMT_chop (line);					/* Rid the world of CR/LF */
+			if (line[0] == '#' || line[0] == '\0') continue;	/* Skip comments and blank lines */
 			n = sscanf (line, "%lf", &z_width[i++]);
 			if (n != 1) {
 				fprintf (stderr, "%s: Error reading file %s near line %ld\n", GMT_program, Ctrl->Z.file, i);
@@ -445,7 +446,7 @@ int main(int argc, char **argv)
 
 	GMT_free ((void *)z_width);
 
-	Free_Psscale_Ctrl (Ctrl);	/* Deallocate control structure */
+	Free_psscale_Ctrl (Ctrl);	/* Deallocate control structure */
 
 	GMT_end (argc, argv);
 
@@ -612,7 +613,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 				x1 += z_width[ii];
 				if ((f = GMT_lut[ii].fill)) {	/* Using pattern fills */
 					xp[0] = xp[3] = x0 + gap;	xp[1] = xp[2] = x1 - gap;
-					GMT_fill (xp, yp, (GMT_LONG)4, f, center);	/* Contours drawn separately below if desired */
+					GMT_fill (xp, yp, (GMT_LONG)4, f, center);	/* Outline drawn separately below if desired */
 				}
 				else if (intens) {
 					nb = (GMT_gray || monochrome) ? 1 : 3;
@@ -646,26 +647,24 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_FGD : GMT_BGD;
 			if ((f = GMT_bfn[id].fill))
-				GMT_fill (xp, yp, (GMT_LONG)3, f, FALSE);	/* Contours drawn separately below if desired */
+				GMT_fill (xp, yp, (GMT_LONG)3, f, TRUE);
 			else {
 				memcpy ((void *)rgb, (void *)GMT_bfn[id].rgb, (size_t)(3 * sizeof (int)));
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
-				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
+				ps_polygon (xp, yp, (GMT_LONG)3, rgb, TRUE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 		if (extend & (2 - reverse)) {	/* Add color triangle on right side */
 			xp[0] = xp[1] = xright + gap;	xp[2] = xp[0] + e_length;
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_BGD : GMT_FGD;
 			if ((f = GMT_bfn[id].fill))
-				GMT_fill (xp, yp, (GMT_LONG)3, f, FALSE);	/* Contours drawn separately below if desired */
+				GMT_fill (xp, yp, (GMT_LONG)3, f, TRUE);
 			else {
 				memcpy ((void *)rgb, (void *)GMT_bfn[id].rgb, (size_t)(3 * sizeof (int)));
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
-				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
+				ps_polygon (xp, yp, (GMT_LONG)3, rgb, TRUE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 
 		if (gap == 0.0) {
@@ -677,8 +676,10 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 
 		if (B_set) {	/* Used -B */
 			GMT_xy_axis (xleft, y_base, length, start_val, stop_val, &frame_info.axis[0], !(flip & 1), frame_info.side[0]-1);
-			dx =  GMT_get_map_interval (0, GMT_GRID_UPPER); 
-			if (dx > 0.0) GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
+			if ((dx = GMT_get_map_interval (0, GMT_GRID_UPPER)) > 0.0) {
+				GMT_setpen (&gmtdefs.grid_pen[0]);
+				GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
+			}
 		}
 		else {
 			/* First draw gridlines, unless skip_lines is TRUE */
@@ -773,7 +774,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 				x1 += z_width[ii];
 				if ((f = GMT_lut[ii].fill)) {	/* Using pattern fills */
 					xp[0] = xp[3] = x0 + gap;	xp[1] = xp[2] = x1 - gap;
-					GMT_fill (xp, yp, (GMT_LONG)4, f, center);	/* Contours drawn separately below if desired */
+					GMT_fill (xp, yp, (GMT_LONG)4, f, center);	/* Outline drawn separately below if desired */
 				}
 				else if (intens) {
 					nb = (GMT_gray || monochrome) ? 1 : 3;
@@ -823,26 +824,24 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_FGD : GMT_BGD;
 			if ((f = GMT_bfn[id].fill))
-				GMT_fill (xp, yp, (GMT_LONG)3, f, FALSE);	/* Contours drawn separately below if desired */
+				GMT_fill (xp, yp, (GMT_LONG)3, f, TRUE);
 			else {
 				memcpy ((void *)rgb, (void *)GMT_bfn[id].rgb, (size_t)(3 * sizeof (int)));
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
-				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
+				ps_polygon (xp, yp, (GMT_LONG)3, rgb, TRUE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 		if (extend & (2 - reverse)) {	/* Add color triangle at top */
 			xp[0] = xp[1] = xright + gap;	xp[2] = xp[0] + e_length;
 			yp[0] = width;	yp[1] = 0.0;	yp[2] = 0.5 * width;
 			id = (reverse) ? GMT_BGD : GMT_FGD;
 			if ((f = GMT_bfn[id].fill))
-				GMT_fill (xp, yp, (GMT_LONG)3, f, FALSE);	/* Contours drawn separately below if desired */
+				GMT_fill (xp, yp, (GMT_LONG)3, f, TRUE);
 			else {
 				memcpy ((void *)rgb, (void *)GMT_bfn[id].rgb, (size_t)(3 * sizeof (int)));
 				if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
-				ps_polygon (xp, yp, (GMT_LONG)3, rgb, FALSE);
+				ps_polygon (xp, yp, (GMT_LONG)3, rgb, TRUE);
 			}
-			ps_polygon (xp, yp, (GMT_LONG)3, GMT_no_rgb, TRUE);
 		}
 		if (gap == 0.0) {
 			ps_segment (xleft, 0.0, xleft + length, 0.0);
@@ -852,8 +851,10 @@ void GMT_draw_colorbar (double length, double width, double *z_width, GMT_LONG b
 		}
 		if (B_set) {	/* Used -B. Must kludge by copying x-axis and scaling to y since we must use GMT_xy_axis to draw a rotated x-axis... */
 			PFL tmp;
-			dx = GMT_get_map_interval (0, GMT_GRID_UPPER); 
-			if (dx > 0.0) GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
+			if ((dx = GMT_get_map_interval (0, GMT_GRID_UPPER)) > 0.0) {
+				GMT_setpen (&gmtdefs.grid_pen[0]);
+				GMT_linearx_grid (GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high, 0.0, width, dx);
+			}
 			ps_transrotate (0.0, 0.0, -90.0);
 			memcpy ((void *)&frame_info.axis[1], (void *)&frame_info.axis[0], sizeof (struct GMT_PLOT_AXIS));
 			d_swap (project_info.x_scale, project_info.y_scale);
@@ -999,10 +1000,10 @@ void fix_format (char *unit, char *format)
 	}
 }
 
-void *New_Psscale_Ctrl () {	/* Allocate and initialize a new control structure */
+void *New_psscale_Ctrl () {	/* Allocate and initialize a new control structure */
 	struct PSSCALE_CTRL *C;
 	
-	C = (struct PSSCALE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSSCALE_CTRL), "New_Psscale_Ctrl");
+	C = (struct PSSCALE_CTRL *) GMT_memory (VNULL, (size_t)1, sizeof (struct PSSCALE_CTRL), "New_psscale_Ctrl");
 	
 	/* Initialize values whose defaults are not 0/FALSE/NULL */
 	C->N.dpi = 300;
@@ -1012,7 +1013,7 @@ void *New_Psscale_Ctrl () {	/* Allocate and initialize a new control structure *
 	return ((void *)C);
 }
 
-void Free_Psscale_Ctrl (struct PSSCALE_CTRL *C) {	/* Deallocate control structure */
+void Free_psscale_Ctrl (struct PSSCALE_CTRL *C) {	/* Deallocate control structure */
 	if (C->C.file) free ((void *)C->C.file);
 	if (C->Z.file) free ((void *)C->Z.file);
 	GMT_free ((void *)C);	
